using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

public class GameManager : MonoBehaviour
{
	public GameObject flamePlayer;
	public GameObject dropPlayer;
	public GameObject dropSteam;
	public GameObject flameSteam;

	public Text status;
	public Text btn;
	public Button tryAgainBtn;
	public Button resumeBtn;
	public Button quitBtn;

	private bool flame;
	private bool gameOver;
	private bool jungleOnFire;
	private bool flameWin, dropWin;
	private bool pause;

    // Start is called before the first frame update
    void Start()
    {
		flamePlayer.GetComponent<Move>().enabled = false;
		flame = false;
		gameOver = false;
		jungleOnFire = false;
		flameWin = dropWin = false;
		pause = false;
    }

    // Update is called once per frame
    void Update()
    {
		if (Input.GetKeyDown(KeyCode.S) && !jungleOnFire)
			SwitchPlayer();

		if (Input.GetKeyDown(KeyCode.Escape))
		{
			if (!pause)
			{
				PauseGame();
				pause = true;
			}
			else {
				ResumeGame();
				pause = false;
			}
		}

		if (gameOver)
		{
			dropSteam.transform.position = new Vector3(dropPlayer.transform.position.x, dropPlayer.transform.position.y, dropPlayer.transform.position.z);
			flameSteam.transform.position = new Vector3(flamePlayer.transform.position.x, flamePlayer.transform.position.y, flamePlayer.transform.position.z);

			dropSteam.GetComponent<Animator>().enabled = true;
			flameSteam.GetComponent<Animator>().enabled = true;

			dropSteam.GetComponent<Animator>().Play("Steam");
			flameSteam.GetComponent<Animator>().Play("Steam");

			status.text = "Game Over!";
			status.gameObject.SetActive(true);
			tryAgainBtn.gameObject.SetActive(true);
		}

		if (jungleOnFire)
		{
			status.text = "Jungle is on Fire!";
			flamePlayer.GetComponent<Move>().enabled = false;
			dropPlayer.GetComponent<Move>().enabled = false;
			status.gameObject.SetActive(true);
			tryAgainBtn.gameObject.SetActive(true);
		}

		if (dropWin && flameWin)
		{
			status.text = "You Win!";
			btn.text = "Play Again";

			status.gameObject.SetActive(true);
			tryAgainBtn.gameObject.SetActive(true);
		}
    }

	public void SwitchPlayer()
	{
		if (!flame)
		{
			dropPlayer.GetComponent<Move>().enabled = false;
			flamePlayer.GetComponent<Move>().enabled = true;
			flame = true;
		} else if (flame) {
			dropPlayer.GetComponent<Move>().enabled = true;
			flamePlayer.GetComponent<Move>().enabled = false;
			flame = false;
		}
	}

	public void GameOver()
	{
		gameOver = true;
	}

	public void JungleOnFire()
	{
		jungleOnFire = true;
	}

	public void FlameWin()
	{
		flameWin = true;
	}

	public void DropWin()
	{
		dropWin = true;
	}

	public void PauseGame()
	{
		Time.timeScale = 0;
		resumeBtn.gameObject.SetActive(true);
		quitBtn.gameObject.SetActive(true);
	}

	public void ResumeGame()
	{
		Time.timeScale = 1;
		resumeBtn.gameObject.SetActive(false);
		quitBtn.gameObject.SetActive(false);
	}

	public void Reload()
	{
		Scene scene = SceneManager.GetActiveScene();
		SceneManager.LoadScene(scene.name);
	}

	public void QuitGame()
	{
		Application.Quit();
	}
}
